@@ -22,8 +22,15 @@
 Collect HBA information
 """
 import glob
-import os
 import logging
+import os
+
+from vdsm import constants
+from vdsm import utils
+from vdsm.config import config
+import zombiereaper
+
+import misc
 
 log = logging.getLogger("Storage.HBA")
 
@@ -36,29 +43,27 @@ PORT_NAME = "port_name"
 NODE_NAME = "node_name"
 
 
+@misc.samplingmethod
 def rescan():
     """
-    Rescan HBAs connections, updating available devices.
-
-    This operation performs a Loop Initialization Protocol (LIP) and then
-    scans the interconnect and causes the SCSI layer to be updated to reflect
-    the devices currently on the bus. A LIP is, essentially, a bus reset, and
-    will cause device addition and removal.
-
-    Bear in mind that issue_lip is an asynchronous operation. The command may
-    complete before the entire scan has completed.
-
-    Note: Must be executed as root.
-    TODO: Some drivers do not support this operation.
+    Rescan HBAs discovering new devices.
     """
-    log.info("Rescanning HBAs")
-    for path in glob.glob(FC_HOST_MASK + '/issue_lip'):
-        log.debug("Issuing lip %s", path)
-        try:
-            with open(path, 'w') as f:
-                f.write('1')
-        except IOError as e:
-            logging.error("Error issuing lip: %s", e)
+    timeout = config.getint('irs', 'scsi_rescan_maximal_timeout')
+
+    log.debug("Starting scan")
+    proc = utils.execCmd([constants.EXT_FC_SCAN], sync=False, sudo=True,
+                         execCmdLogger=log)
+    try:
+        proc.wait(timeout)
+    finally:
+        if proc.returncode is None:
+            log.warning("Timeout scanning")
+            zombiereaper.autoReapPID(proc.pid)
+        elif proc.returncode != 0:
+            stderr = proc.stderr.read(512)
+            log.error("Scan failed: %r", stderr)
+        else:
+            log.debug("Scan finished")
 
 
 def getiSCSIInitiators():
